==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-core/src/main/java/org/apache/geode/internal/cache/eviction/EvictionListBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.eviction;

import java.util.Optional;

import org.apache.geode.internal.lang.SystemPropertyHelper;

public class EvictionListBuilder {

  private final boolean evictionScanAsync;

  private final EvictionController controller;

  public EvictionListBuilder(EvictionController evictionController) {
    this.controller = evictionController;
    Optional<Boolean> asyncScan =
        SystemPropertyHelper.getProductBooleanProperty(SystemPropertyHelper.EVICTION_SCAN_ASYNC);
    evictionScanAsync = asyncScan.orElse(true);
  }

  public EvictionList create() {
    if (this.controller.getEvictionAlgorithm().isLIFO()) {
      return new LIFOList(this.controller);
    } else {
      if (evictionScanAsync) {
        return new LRUListWithAsyncSorting(this.controller);
      } else {
        return new LRUListWithSyncSorting(this.controller);
      }
    }
  }

}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/internal/cache/eviction/EvictionListBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.eviction;

import java.util.Optional;

import org.apache.geode.internal.lang.SystemProperty;
import org.apache.geode.internal.lang.SystemPropertyHelper;

public class EvictionListBuilder {

  private final boolean evictionScanAsync;

  private final EvictionController controller;

  public EvictionListBuilder(EvictionController evictionController) {
    controller = evictionController;
    Optional<Boolean> asyncScan =
        SystemProperty.getProductBooleanProperty(SystemPropertyHelper.EVICTION_SCAN_ASYNC);
    evictionScanAsync = asyncScan.orElse(true);
  }

  public EvictionList create() {
    if (controller.getEvictionAlgorithm().isLIFO()) {
      return new LIFOList(controller);
    } else {
      if (evictionScanAsync) {
        return new LRUListWithAsyncSorting(controller);
      } else {
        return new LRUListWithSyncSorting(controller);
      }
    }
  }

}
